@@ -22,6 +22,7 @@ except Exception:
 from climetlab.core.caching import temp_file
 from climetlab.core.ipython import SVG, Image
 from climetlab.core.data import get_data_entry
+from climetlab.core.metadata import annotation
 
 LOG = logging.getLogger(__name__)
 
@@ -142,7 +143,7 @@ class Driver:
         )
 
         self._foreground = mcoast(
-            map_grid=True,
+            map_grid=False,
             map_label=False,
             map_grid_frame=True,
             map_grid_frame_thickness=5,
@@ -321,6 +322,12 @@ class Driver:
         frame[[latitude, longitude, variable]].to_csv(tmp, header=False, index=False)
         self.plot_csv(tmp, variable)
 
+        print(frame._metadata)
+
+        style = annotation(frame).get("style")
+        if style is not None:
+            self.style(style)
+
     def _apply(self, collection, value, action):
 
         if value is None:
@@ -380,18 +387,23 @@ class Driver:
         frame = self.option("frame", False)
 
         if self.option("grid", False):
-            self._grid = mmap(map_grid=True, map_coastline=False)
+            self._grid = mcoast(map_grid=True, map_coastline=False)
 
         if self.option("borders", False):
-            self._borders = mmap(
+            self._borders = mcoast(
                 map_boundaries=True, map_grid=False, map_coastline=False
             )
 
         if self.option("rivers", False):
-            self._rivers = mmap(map_rivers=True, map_grid=False, map_coastline=False)
+            self._rivers = mcoast(
+                map_rivers=True,
+                map_grid=False,
+                map_coastline=False,
+                map_coastline_resolution="high",
+            )
 
         if self.option("cities", False):
-            self._cities = mmap(map_cities=True, map_grid=False, map_coastline=False)
+            self._cities = mcoast(map_cities=True, map_grid=False, map_coastline=False)
 
         path = self.option(
             "path", self.temporary_file("." + self.option("format", "png"))
@@ -445,9 +457,6 @@ class Driver:
 
         args = [page] + self.macro()
 
-        # for a in args:
-        #     print(a)
-
         try:
             macro.plot(*args)
         except Exception:
